Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(349)

Unified Diff: src/interpreter/interpreter.cc

Issue 2587393006: [runtime] Collect IC feedback in DefineDataPropertyInLiteral. (Closed)
Patch Set: Minor clean ups, implement print and clear methods. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/interpreter/interpreter.cc
diff --git a/src/interpreter/interpreter.cc b/src/interpreter/interpreter.cc
index 724c159c5eeedd1bae69eef33e932490aa58d540..1c9af43a6ac54dfed78a1a471328e1ca4fa76801 100644
--- a/src/interpreter/interpreter.cc
+++ b/src/interpreter/interpreter.cc
@@ -818,27 +818,26 @@ void Interpreter::DoStaKeyedPropertyStrict(InterpreterAssembler* assembler) {
DoKeyedStoreIC(ic, assembler);
}
-// StaDataPropertyInLiteral <object> <name> <value> <flags>
+// StaDataPropertyInLiteral <object> <name> <flags>
//
// Define a property <name> with value <value> in <object>. Property attributes
// and whether set_function_name are stored in DataPropertyInLiteralFlags
// <flags>.
//
// This definition is not observable and is used only for definitions
// in object or class literals.
void Interpreter::DoStaDataPropertyInLiteral(InterpreterAssembler* assembler) {
- Node* object_reg_index = __ BytecodeOperandReg(0);
- Node* object = __ LoadRegister(object_reg_index);
- Node* name_reg_index = __ BytecodeOperandReg(1);
- Node* name = __ LoadRegister(name_reg_index);
- Node* value_reg_index = __ BytecodeOperandReg(2);
- Node* value = __ LoadRegister(value_reg_index);
- Node* flags = __ SmiFromWord32(__ BytecodeOperandFlag(3));
+ Node* object = __ LoadRegister(__ BytecodeOperandReg(0));
+ Node* name = __ LoadRegister(__ BytecodeOperandReg(1));
+ Node* value = __ GetAccumulator();
+ Node* flags = __ SmiFromWord32(__ BytecodeOperandFlag(2));
+ Node* vector_index = __ SmiTag(__ BytecodeOperandIdx(3));
+ Node* type_feedback_vector = __ LoadTypeFeedbackVector();
Node* context = __ GetContext();
__ CallRuntime(Runtime::kDefineDataPropertyInLiteral, context, object, name,
- value, flags);
+ value, flags, type_feedback_vector, vector_index);
__ Dispatch();
}
@@ -818,27 +818,26 @@ void Interpreter::DoStaKeyedPropertyStrict(InterpreterAssembler* assembler) {
//
-// Define a property <name> with value <value> in <object>. Property attributes
-// and whether set_function_name are stored in DataPropertyInLiteralFlags
-// <flags>.
+// Define a property <name> with value from the accumulator in <object>.
+// Property attributes and whether set_function_name are stored in
+// DataPropertyInLiteralFlags <flags>.
//
// This definition is not observable and is used only for definitions

Powered by Google App Engine
This is Rietveld 408576698